;This file is copyright (c) 1991, 1992 Informant Communications Group and the
;article author. The material here may be used in an application provided
;that this copyright/disclaimer information is kept in the original source
;file. The material presented here is provided "as is" and with no guarantee.
;Informant Communications Group/Paradox Informant assume no responsibility
;for the use or misuse of the material contained within.
;
;Contents        : procedures Individual_Tables_Lists.U, 
;                             Individual_Tables_Lists1.U
;Source File     : ARRAYS1.SC
;Author          : Cynthia Weisfield
;                  Advocate Computerization Services
;                  Pittsburgh, PA
;                  (412) 831-2256
;
;Informant Issue : September 1992
;
;Description     : This procedure gets input from the user as to whether a 
;                  particular table is to be printed. The input begins on 
;                  row 6 of the screen and goes to line 14 to reference table
;                  names. Line 15 is for confirmation of the input. The goal 
;                  is to get all input with one variable and only use the
;                  following SWITCH structure to check for whether the input 
;                  is for an acceptance line or for an individual report.
;                  The alternative way to handle the input is to size the 
;                  array for 9 and then test what line number the input screen
;                  is on and assign the actual name of the table to that cell 
;                  in the array. The first cell is still for ALL tables. The 
;                  specific table names are loaded separately and printed in
;                  relation to the instruction in cell 6-14.
;                  Since line 6 is the beginning of the entries, cells 1-5 are 
;                  not used although they are loaded with N for ease of 
;                  operation. Note that locking tests are not included in this 
;                  script. You may want to substitute a call to your own 
;                  messaging procedure instead of using the PAL MESSAGE command.
;
; Paradox Informant
; 10519 E. Stockton Blvd.
; Suite 142
; Elk Grove, CA  95624-9743
; Phone: (916) 686-6610
; Fax  : (916) 686-8497
; BBS  : (916) 686-4740

PROC INDIVIDUAL_TABLES_LISTS.U()
PRIVATE  X,Z,Q,              ; constructs for loops
         ITREPORTS,          ; name of array
         ALLLISTS.V          ; input varible
X=BLANKNUM()                 ; initialize variables
Z=BLANKNUM()
Q=BLANKNUM()
ALLLISTS.V=""

CLEAR
PAINTCANVAS BORDER FILL CHR(47)   ; paint screen
ATTRIBUTE 10
0,0,24,79

STYLE ATTRIBUTE 10
@1,10                             ; provide a heading
??FORMAT("W61,AC","PRINT INDIVIDUAL TABLES")
STYLE

; Fill array for printing reports
; All reports are initially assumed to be N to not print
ARRAY ITREPORTS[24]               ; array to 24 cells
; 6 are unused, 8 for Yes or No to print, 8 for the table names
; Each table has a single report, R, to print a listing from

FOR Z FROM 1 TO 24
  ITREPORTS[X]="N"
  ; Set each cell to N to not print as an initial assumption
ENDFOR

; The following section loads the array cell with the name
; of the table for printing. Each entry is the name of a table.
ITREPORTS[16]="ALL"
ITREPORTS[17]="DEPTHEAD"
ITREPORTS[18]="DEPT"
ITREPORTS[19]="COMMHEAD"
ITREPORTS[20]="COMM"
ITREPORTS[21]="SPECIAL"
ITREPORTS[22]="BLDGCODE"
ITREPORTS[23]="DEGREES"
ITREPORTS[24]="CERT"

@3,2
??FORMAT("W77,AC","Enter Y for Yes, N for No, or S at OKAY to STOP.")
@6,20  ??"1.  ALL REPORT LISTINGS:"    ; Print all tables
@7,20  ??"2.  DEPARTMENT HEADS:"       ; DEPTHEAD table
@8,20  ??"3.  DEPARTMENTS:"            ; DEPT table
@9,20  ??"4.  COMMITTEES HEADS:"       ; COMMHEAD table
@10,20 ??"5.  COMMITTEES:"             ; COMM table
@11,20 ??"6.  SPECIALIZATIONS:"        ; SPECIAL table
@12,20 ??"7.  BUILDING CODES:"         ; BLDGCODE table
@13,20 ??"8.  DEGREES:"                ; DEGREE table
@14,20 ??"9.  CERTIFICATES:"           ; CERT table
@15,20 ??"    OKAY? (Y/N/S)   "        ; Confirmation line

WHILE TRUE
  FOR X FROM 6 TO 15   ; Z corresponds to same cell number in array
    @X,50
    ACCEPT "A1"        ; Get input from user
    TO ALLLISTS.V      ; Note one variable is used for all entries

    SWITCH
      CASE X<>15 AND ALLLISTS.V<>"Y" AND ALLLISTS.V<>"N":
      ; input must be Yes or No
      MESSAGE("ENTER 'Y' OR 'N'.")
      ; for lines where individual tables are referenced
      SLEEP 1000
      X=X-1
      LOOP

      CASE X=15 AND ALLLISTS.V<>"Y" AND ALLLISTS.V<>"S":
      ; The acceptance line is Yes or Stop
      MESSAGE("ENTER 'Y', OR 'S'.")
      X=X-1
      LOOP

      CASE X=6 AND ALLLISTS.V="Y":
      ; If Y for all then jump directly to confirmation line
      ITREPORTS[X]="Y"
      ; All cells of array are loaded with "Y"
      X=14
      LOOP

      CASE X<>15 AND ALLLISTS.V="N":
      ; If input is N, then array is loaded with "N"s
      ITREPORTS[X]="N"
      LOOP

      CASE X<>15 AND ALLLISTS.V="Y":
      ; if input is Y, then array is loaded with "Y"s
      ITREPORTS[X]="Y"
      LOOP

      CASE X=15 AND ALLLISTS.V="Y":
      ; If acceptance is Y, then go to second procedure
      INDIVIDUAL_TABLES_LIST1.U()
      QUITLOOP

      CASE X=15 AND ALLLISTS.V="S":
      ; If acceptance is S then go back to menu
      QUITLOOP

      CASE Z=15 AND ALLLISTS.V="N":
      ; If acceptance is N then loop and begin again
      LOOP

      OTHERWISE:
      LOOP
    ENDSWITCH
  ENDFOR

  IF ALLLISTS.V="Y" THEN QUITLOOP ENDIF
  ; When finished, quit inside loop
  IF ALLLISTS.V="S" THEN QUITLOOP ENDIF
  ; When finished, quit inside loop
ENDWHILE

CLEAR                   ; calling procedure cleans everything up
CLEARALL
RESET
ENDPROC
WRITELIB "YOURLIB" INDIVIDUAL_TABLES_LISTS.U
; Write procedure out
RELEASE PROCS INDIVIDUIAL_TABLES_LISTS.U
; Release for memory conservation

;PROCEDURE TO HANDLE OVERFLOW:  keep procedure bytes small
PROC INDIVIDUAL_TABLES_LIST1.U()

PAINTCANVAS BORDER FILL CHR(47)
; Replace border after clear
ATTRIBUTE 10
0,0,24,79

; user messages
@4,1 ??"The reports are being printed."
STYLE ATTRIBUTE 138
@5,1 ??"PLEASE WAIT."
STYLE
@8,1 ??"PRINTING REPORT: "
; Header for report notification to user

FOR Z FROM 6 TO 14        ; 8 possible choices, lines 6-14
  ; array cell 6 references line 6 on screen
  IF Z=6 AND ITREPORTS[N]="Y" THEN
    ; Check choice to print (Y) or not print (N)
    ; Array is referenced against line 6 of the
    ; input screen was for all reports
    ; If it is Y then all reports are to print
    FOR Q FROM 17 TO 24
      ; Array cells 17 to 24 have the names of the tables
      ; This nested loop gets each name
      PAINTCANVAS ATTRIBUTE 0 6,1,6,25
      ; Notify user of report that is printing
      @6,1 ??ITREPORTS[Q]
      REPORT ITREPORTS[Q] "R"
      ; ITREPORTS[Q] refers to a table and print only report R
    ENDFOR
  ; When done with all of them, quit and return
  QUITLOOP
  ENDIF

  IF ITREPORTS[N]="Y" THEN
    ; If all reports are not to be printed, then get those that are
    PAINTCANVAS ATTRIBUTE 0 6,1,6,25
    @6,1 ??ITREPORTS[Z+10]
    ; Print reference to outer FOR nest
    REPORT ITREPORTS[N+10] "R"
    ; The number in the outer FOR loop plus 10 references the
    ; correct report: if N is 8 then the cell referenced is 18 which
    ; is the DEPT table
  ENDIF
ENDFOR

ENDPROC

WRITELIB "YOURLIB" INDIVIDUAL_TABLES_LISTS1.U
RELEASE PROCS INDIVIDUAL_TABLES_LISTS1.U
